tpDcc-config
============================================================

tpDcc module that contains configuration files

.. image:: https://travis-ci.com/tpRigToolkit/tpDcc-config.svg?branch=master&kill_cache=1
    :target: https://travis-ci.com/tpRigToolkit/tpDcc-config

.. image:: https://coveralls.io/repos/github/tpRigToolkit/tpDcc-config/badge.svg?branch=master&kill_cache=1
    :target: https://coveralls.io/github/tpRigToolkit/tpDcc-config?branch=master

.. image:: https://img.shields.io/badge/docs-sphinx-orange
    :target: https://tpRigToolkit.github.io/tpDcc-config/

.. image:: https://img.shields.io/github/license/tpDcc/tpRigToolkit-config
    :target: https://github.com/tpRigToolkit/tpDcc-config/blob/master/LICENSE

.. image:: https://img.shields.io/pypi/v/tpDcc-config?branch=master&kill_cache=1
    :target: https://pypi.org/project/tpDcc-config/

.. image:: https://img.shields.io/badge/code_style-pep8-blue
    :target: https://www.python.org/dev/peps/pep-0008/